@@ -17,7 +17,7 @@
 # specific language governing permissions and limitations
 # under the License.
 
-#coding=utf-8
+# coding=utf-8
 
 """
 Acs error message module.
@@ -27,11 +27,13 @@ Created on 6/15/2015
 @author: alex jiang
 """
 
-__dict = dict(SDK_INVALID_REGION_ID='Can not find endpoint to access.',
-              SDK_SERVER_UNREACHABLE='Unable to connect server',
-              SDK_INVALID_REQUEST='The request is not a valid AcsRequest.',
-              SDK_MISSING_ENDPOINTS_FILER='Internal endpoints info is missing.')
+__dict = dict(
+    SDK_INVALID_REGION_ID='Can not find endpoint to access.',
+    SDK_SERVER_UNREACHABLE='Unable to connect server',
+    SDK_INVALID_REQUEST='The request is not a valid AcsRequest.',
+    SDK_MISSING_ENDPOINTS_FILER='Internal endpoints info is missing.',
+    SDK_UNKNOWN_SERVER_ERROR="Can not parse error message from server response.")
 
 
 def get_msg(code):
-	return __dict.get(code)
+    return __dict.get(code)
